import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { range, line, curveLinearClosed } from 'd3';

// Tweak these.
// const nodeNumber = 7;
const radius = 200;
//const skipFactor = 6.25;

const width = 960;
const height = 960;
const centerX = width / 2;
const centerY = height / 2;

const polyline = line()
  .x(d => d.x)
  .y(d => d.y)
  .curve(curveLinearClosed);

const gray = n => `rgb(${n},${n},${n})`;

const speedGenerate = 16;

const App = () => {
  const [skipFactor, setSkipFactor] = useState(1);
  const [nodeNumber, setNodeNumber] = useState(3);

  useEffect(() => {
    setTimeout(() => {
      if (skipFactor > nodeNumber) {
        setNodeNumber(nodeNumber + 1);
        setSkipFactor(0);
      } else {
        setSkipFactor(skipFactor + 0.01);
      }
    }, speedGenerate);
  }, [skipFactor]);

  //console.log('nodeNumber=' + nodeNumber, 'skipFactor=' + skipFactor);

  const data = range(nodeNumber).map(i => ({
    x: Math.sin((i / nodeNumber) * Math.PI * 2 * skipFactor) * radius,
    y: Math.cos((i / nodeNumber) * Math.PI * 2 * skipFactor) * radius
  }));

  const p1 = data[0];
  const p2 = data[1];
  const dx = p1.x - p2.x;
  const dy = p1.y - p2.y;
  const segmentLength = Math.sqrt(dx * dx + dy * dy);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${centerX},${centerY})`}>
        {data.map((d, i) => (
          <circle
            cx={d.x}
            cy={d.y}
            r={segmentLength}
            // fill={i === 7 ? "red":"none"}
            fill={'none'}
            strokeWidth={2}
            stroke={gray(180)}
          />
        ))}
        {
          <path
            fill="none"
            stroke="#3866e9"
            strokeWidth={5}
            opacity={.25}
            d={polyline(data)}
          />
        }
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
